==> nodus-framework-0.1.8.tgz: package/plugins/redis.js <==
'use strict';

const DEFAULT_REDIS_HOST = 'localhost';
const DEFAULT_REDIS_PORT = 6379;
const DEFAULT_STATS_INTERVAL = 10 * 1000;

// ** Dependencies
const Promise = require('bluebird');
const redis = Promise.promisifyAll(require("redis"));
const logger = require('../lib/logging').createLogger('redis-plugin');
const errors = require('../lib/errors');
const program = require('../lib/program');
const os = require('os');

function loadPlugin(server, service) {

    // Redis Configuration
    const redis_host = process.env['REDIS_HOST'] || DEFAULT_REDIS_HOST;
    const redis_port = process.env['REDIS_PORT'] || DEFAULT_REDIS_PORT;
    const stats_interval = Number(process.env['NODUS_STATS_INTERVAL'] || DEFAULT_STATS_INTERVAL);

    // Create Redis client
    const client = redis.createClient(redis_port, redis_host);

    // Shutdown client on shutdown
    program.on('shutdown', () => {

        // Try to postpone this event to the last one
        process.nextTick(() =>
            setTimeout(() => {
                logger.debug('Closing REDIS client...');
                client.quit();
            }, 100));
    });

    // Publish Service Events
    const service_name = service.name;
    const hostname = os.hostname();

    function publish(payload) {
        return client
            .publishAsync('events', JSON.stringify(payload))
            .catch(err => {
                logger.debug(errors('PUBLISH_ERROR', 'An error occurred publish event to redis', payload));
            });
    }

    // Publish all service events to redis
    function publish_event(event) {

        logger.debug('REDIS_CAPTURE_EVENT', {event: event});
        service.on(event, function () {

            logger.debug('ARGUMENTS', arguments);

            const payload = {
                timestamp: new Date().toISOString(),
                service: service_name,
                hostname: hostname,
                event: event,
                data: arguments
            };

            logger.debug('PUBLISH', payload);
            return publish(payload);
        });
    }

    // Publish service 'started' and 'stopped' events
    publish_event('started');
    publish_event('stopped');
    publish_event('request');

    // Set timer to publish stats event on an interval
    if (stats_interval > 0) {
        logger.debug('PUBLISH_STATS', {interval: stats_interval});

        const publish_stats = () => {
            logger.debug('PUBLISH_STATS', {service: service_name});

            // Publish Stats over redis
            publish({
                service: service_name,
                hostname: hostname,
                stats: service.stats
            });
        };

        const i = setInterval(publish_stats, stats_interval).unref();

        // ** Stop timer on shutdown
        service.on('stopped', () => {
            logger.debug('Disabling stats timer...', {service: service_name});
            clearInterval(i);

            logger.debug('Publishing final stats...', {service: service_name});
            publish_stats();
        });
    } else {
        logger.debug('PUBLISH_STATS_DISABLED');
    }
}

// ** Exports
module.exports = loadPlugin;

==> nodus-framework-0.5.9.tgz: package/plugins/redis.js <==
'use strict';

const DEFAULT_REDIS_HOST = 'localhost';
const DEFAULT_REDIS_PORT = 6379;
const DEFAULT_STATS_INTERVAL = 10 * 1000;

// ** Dependencies
const Promise = require('bluebird');
const redis = Promise.promisifyAll(require("redis"));
const logger = require('../lib/logger').createLogger('redis-plugin');
const errors = require('../lib/errors');
const program = require('../lib/program');
const os = require('os');

function loadPlugin(server, service) {

    // Redis Configuration
    const redis_host = process.env['REDIS_HOST'] || DEFAULT_REDIS_HOST;
    const redis_port = process.env['REDIS_PORT'] || DEFAULT_REDIS_PORT;
    const stats_interval = Number(process.env['NODUS_STATS_INTERVAL'] || DEFAULT_STATS_INTERVAL);

    // Create Redis client
    const client = redis.createClient(redis_port, redis_host);

    // Shutdown client on shutdown
    program.on('shutdown', () => {

        // Try to postpone this event to the last one
        process.nextTick(() =>
            setTimeout(() => {
                logger.debug('Closing REDIS client...');
                client.quit();
            }, 100));
    });

    // Publish Service Events
    const service_name = service.name;
    const hostname = os.hostname();

    function publish(payload) {
        return client
            .publishAsync('events', JSON.stringify(payload))
            .catch(err => {
                logger.debug(errors('PUBLISH_ERROR', 'An error occurred publish event to redis', payload));
            });
    }

    // Publish all service events to redis
    function publish_event(event) {

        logger.debug('REDIS_CAPTURE_EVENT', {event: event});
        service.on(event, function () {

            logger.debug('ARGUMENTS', arguments);

            const payload = {
                timestamp: new Date().toISOString(),
                service: service_name,
                hostname: hostname,
                event: event,
                data: arguments
            };

            logger.debug('PUBLISH', payload);
            return publish(payload);
        });
    }

    // Publish service 'started' and 'stopped' events
    publish_event('started');
    publish_event('stopped');
    publish_event('request');

    // Set timer to publish stats event on an interval
    if (stats_interval > 0) {
        logger.debug('PUBLISH_STATS', {interval: stats_interval});

        const publish_stats = () => {
            logger.debug('PUBLISH_STATS', {service: service_name});

            // Publish Stats over redis
            publish({
                service: service_name,
                hostname: hostname,
                stats: service.stats
            });
        };

        const i = setInterval(publish_stats, stats_interval).unref();

        // ** Stop timer on shutdown
        service.on('stopped', () => {
            logger.debug('Disabling stats timer...', {service: service_name});
            clearInterval(i);

            logger.debug('Publishing final stats...', {service: service_name});
            publish_stats();
        });
    } else {
        logger.debug('PUBLISH_STATS_DISABLED');
    }
}

// ** Exports
module.exports = loadPlugin;
